@@ -1,9 +1,5 @@
 package Net::Hadoop::YARN;
-$Net::Hadoop::YARN::VERSION = '0.100';
-{
-  $Net::Hadoop::YARN::DIST = 'Net-Hadoop-YARN';
-}
-
+$Net::Hadoop::YARN::VERSION = '0.201';
 use strict;
 use warnings;
 use 5.10.0;
@@ -28,7 +24,7 @@ Net::Hadoop::YARN
 
 =head1 VERSION
 
-version 0.100
+version 0.201
 
 =head1 SYNOPSIS
 
