@@ -1,9 +1,5 @@
 package Net::Hadoop::YARN::ApplicationMaster;
-$Net::Hadoop::YARN::ApplicationMaster::VERSION = '0.100';
-{
-  $Net::Hadoop::YARN::ApplicationMaster::DIST = 'Net-Hadoop-YARN';
-}
-
+$Net::Hadoop::YARN::ApplicationMaster::VERSION = '0.201';
 use strict;
 use warnings;
 use 5.10.0;
@@ -74,7 +70,7 @@ Net::Hadoop::YARN::ApplicationMaster
 
 =head1 VERSION
 
-version 0.100
+version 0.201
 
 =head1 NAME
 
