@@ -1,9 +1,5 @@
 package Net::Hadoop::YARN::NodeManager;
-$Net::Hadoop::YARN::NodeManager::VERSION = '0.100';
-{
-  $Net::Hadoop::YARN::NodeManager::DIST = 'Net-Hadoop-YARN';
-}
-
+$Net::Hadoop::YARN::NodeManager::VERSION = '0.201';
 use strict;
 use warnings;
 use 5.10.0;
@@ -75,7 +71,7 @@ Net::Hadoop::YARN::NodeManager
 
 =head1 VERSION
 
-version 0.100
+version 0.201
 
 =head1 METHODS
 
@@ -91,16 +87,14 @@ Applications API & Application API
 
 parameters are either a hash(/ref) or an application ID
 
-=item state
+=head2 state
 
 application state 
 
-=item user
+=head2 user
 
 user name
 
-=back
-
 =head2 containers
 
 =head2 container
