@@ -1,9 +1,5 @@
 package Net::Hadoop::YARN::Roles::Common;
-$Net::Hadoop::YARN::Roles::Common::VERSION = '0.100';
-{
-  $Net::Hadoop::YARN::Roles::Common::DIST = 'Net-Hadoop-YARN';
-}
-
+$Net::Hadoop::YARN::Roles::Common::VERSION = '0.201';
 use strict;
 use warnings;
 use 5.10.0;
@@ -298,7 +294,7 @@ Net::Hadoop::YARN::Roles::Common
 
 =head1 VERSION
 
-version 0.100
+version 0.201
 
 =head1 AUTHOR
 
